==> netdata_1.19.0.orig.tar.xz: netdata-1.19.0/REDISTRIBUTED.md <==
# Redistributed software

Netdata copyright info:
 Copyright 2016-2018, Costa Tsaousis.
 Copyright 2018, Netdata Inc.
 Released under [GPL v3 or later](LICENSE).

Netdata uses SPDX license tags to identify the license for its files.
Individual licenses referenced in the tags are available on the [SPDX project site](http://spdx.org/licenses/).

Netdata redistributes the following third-party software.
We have decided to redistribute all these, instead of using them
through a CDN, to allow Netdata to work in cases where Internet
connectivity is not available.

-   [Dygraphs](http://dygraphs.com/)

      Copyright 2009, Dan Vanderkam
      [MIT License](http://dygraphs.com/legal.html)

-   [Easy Pie Chart](https://rendro.github.io/easy-pie-chart/)

      Copyright 2013, Robert Fleischmann
      [MIT License](https://github.com/rendro/easy-pie-chart/blob/master/LICENSE)

-   [Gauge.js](http://bernii.github.io/gauge.js/)

      Copyright, Bernard Kobos
      [MIT License](https://github.com/getgauge/gauge-js/blob/master/LICENSE)

-   [d3pie](https://github.com/benkeen/d3pie)

      Copyright (c) 2014-2015 Benjamin Keen
      [MIT License](https://github.com/benkeen/d3pie/blob/master/LICENSE)

-   [jQuery Sparklines](http://omnipotent.net/jquery.sparkline/)

      Copyright 2009-2012, Splunk Inc.
      [New BSD License](http://opensource.org/licenses/BSD-3-Clause)

-   [Peity](http://benpickles.github.io/peity/)

      Copyright 2009-2015, Ben Pickles
      [MIT License](https://github.com/benpickles/peity/blob/master/LICENCE)

-   [morris.js](http://morrisjs.github.io/morris.js/)

      Copyright 2013, Olly Smith
      [Simplified BSD License](http://morrisjs.github.io/morris.js/)

-   [Raphaël](http://dmitrybaranovskiy.github.io/raphael/)

      Copyright 2008, Dmitry Baranovskiy
      [MIT License](http://dmitrybaranovskiy.github.io/raphael/license.html)

-   [C3](http://c3js.org/)

      Copyright 2013, Masayuki Tanaka
      [MIT License](https://github.com/masayuki0812/c3/blob/master/LICENSE)

-   [D3](http://d3js.org/)

      Copyright 2015, Mike Bostock
      [BSD License](http://opensource.org/licenses/BSD-3-Clause)

-   [jQuery](https://jquery.org/)

      Copyright 2015, jQuery Foundation
      [MIT License](https://jquery.org/license/)

-   [Bootstrap](http://getbootstrap.com/getting-started/)

      Copyright 2015, Twitter
      [MIT License](https://github.com/twbs/bootstrap/blob/v4-dev/LICENSE)

-   [Bootstrap Toggle](http://www.bootstraptoggle.com/)

      Copyright (c) 2011-2014 Min Hur, The New York Times Company
      [MIT License](https://github.com/minhur/bootstrap-toggle/blob/master/LICENSE)

-   [Bootstrap-slider](http://seiyria.com/bootstrap-slider/)

      Copyright 2017 Kyle Kemp, Rohit Kalkur, and contributors
      [MIT License](https://github.com/seiyria/bootstrap-slider/blob/master/LICENSE.md)

-   [bootstrap-table](http://bootstrap-table.wenzhixin.net.cn/)

      Copyright (c) 2012-2016 Zhixin Wen [wenzhixin2010@gmail.com](mailto:wenzhixin2010@gmail.com)
      [MIT License](https://github.com/wenzhixin/bootstrap-table/blob/master/LICENSE)

-   [tableExport.jquery.plugin](https://github.com/hhurz/tableExport.jquery.plugin)

      Copyright (c) 2015,2016 hhurz
      [MIT License](https://github.com/hhurz/tableExport.jquery.plugin/blob/master/LICENSE)

-   [perfect-scrollbar](https://jamesflorentino.github.io/nanoScrollerJS/)

      Copyright 2016, Hyunje Alex Jun and other contributors
      [MIT License](https://github.com/noraesae/perfect-scrollbar/blob/master/LICENSE)

-   [FontAwesome](https://fortawesome.github.io/Font-Awesome/)

      Created by Dave Gandy
      Font license: [SIL OFL 1.1](http://scripts.sil.org/OFL)
      Icon license [Creative Commons Attribution 4.0 (CC-BY 4.0)](https://creativecommons.org/licenses/by/4.0/)
      Code license: [MIT License](http://opensource.org/licenses/mit-license.html)

-   [node-extend](https://github.com/justmoon/node-extend)

      Copyright 2014, Stefan Thomas
      [MIT License](https://github.com/justmoon/node-extend/blob/master/LICENSE)

-   [node-net-snmp](https://github.com/stephenwvickers/node-net-snmp)

      Copyright 2013, Stephen Vickers
      [MIT License](https://github.com/nospaceships/node-net-snmp#license)

-   [node-asn1-ber](https://github.com/stephenwvickers/node-asn1-ber)

      Copyright 2017, Stephen Vickers
      Copyright 2011, Mark Cavage
      [MIT License](https://github.com/nospaceships/node-asn1-ber#license)

-   [pixl-xml](https://github.com/jhuckaby/pixl-xml)

      Copyright 2015, Joseph Huckaby
      [MIT License](https://github.com/jhuckaby/pixl-xml#license)

-   [sensors](https://github.com/paroj/sensors.py)

      Copyright 2014, Pavel Rojtberg
      [LGPL 2.1 License](http://opensource.org/licenses/LGPL-2.1)

-   [PyYAML](https://bitbucket.org/blackjack/pysensors)

      Copyright 2006, Kirill Simonov
      [MIT License](https://github.com/yaml/pyyaml/blob/master/LICENSE)

-   [urllib3](https://github.com/shazow/urllib3)

      Copyright 2008-2016 Andrey Petrov and [contributors](https://github.com/shazow/urllib3/blob/master/CONTRIBUTORS.txt)
      [MIT License](https://github.com/shazow/urllib3/blob/master/LICENSE.txt)

-   [lz-string](http://pieroxy.net/blog/pages/lz-string/index.html)

      Copyright 2013 Pieroxy
      [WTFPL License](http://pieroxy.net/blog/pages/lz-string/index.html#inline_menu_10)

-   [pako](http://nodeca.github.io/pako/)

      Copyright 2014-2017 Vitaly Puzrin and Andrei Tuputcyn
      [MIT License](https://github.com/nodeca/pako/blob/master/LICENSE)

-   [clipboard-polyfill](https://github.com/lgarron/clipboard-polyfill)

      Copyright (c) 2014 Lucas Garron
      [MIT License](https://github.com/lgarron/clipboard-polyfill/blob/master/LICENSE.md)

-   [Utilities for writing code that runs on Python 2 and 3](collectors/python.d.plugin/python_modules/urllib3/packages/six.py)

      Copyright (c) 2010-2015 Benjamin Peterson
      [MIT License](https://github.com/benjaminp/six/blob/master/LICENSE)

-   [mcrcon](https://github.com/barneygale/MCRcon)

      Copyright (C) 2015 Barnaby Gale
      [MIT License](https://raw.githubusercontent.com/barneygale/MCRcon/master/COPYING.txt)

-   [monotonic](https://github.com/atdt/monotonic)

      Copyright 2014, 2015, 2016 Ori Livneh [ori@wikimedia.org](mailto:ori@wikimedia.org)
      [Apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

[![analytics](https://www.google-analytics.com/collect?v=1&aip=1&t=pageview&_s=1&ds=github&dr=https%3A%2F%2Fgithub.com%2Fnetdata%2Fnetdata&dl=https%3A%2F%2Fmy-netdata.io%2Fgithub%2FREDISTRIBUTED&_u=MAC~&cid=5792dfd7-8dc4-476b-af31-da2fdb9f93d2&tid=UA-64295674-3)](<>)

==> netdata_1.33.1.orig.tar.xz: netdata-1.33.1/REDISTRIBUTED.md <==
<!--
title: "Redistributed software"
custom_edit_url: https://github.com/netdata/netdata/edit/master/REDISTRIBUTED.md
-->

# Redistributed software

Netdata copyright info:
 Copyright 2016-2018, Costa Tsaousis.
 Copyright 2018, Netdata Inc.
 Released under [GPL v3 or later](https://raw.githubusercontent.com/netdata/netdata/master/LICENSE).

Netdata uses SPDX license tags to identify the license for its files.
Individual licenses referenced in the tags are available on the [SPDX project site](http://spdx.org/licenses/).

Netdata redistributes the following third-party software.
We have decided to redistribute all these, instead of using them
through a CDN, to allow Netdata to work in cases where Internet
connectivity is not available.

-   [Dygraphs](http://dygraphs.com/)

      Copyright 2009, Dan Vanderkam
      [MIT License](http://dygraphs.com/legal.html)

-   [Easy Pie Chart](https://rendro.github.io/easy-pie-chart/)

      Copyright 2013, Robert Fleischmann
      [MIT License](https://github.com/rendro/easy-pie-chart/blob/master/LICENSE)

-   [Gauge.js](http://bernii.github.io/gauge.js/)

      Copyright, Bernard Kobos
      [MIT License](https://github.com/getgauge/gauge-js/blob/master/LICENSE)

-   [d3pie](https://github.com/benkeen/d3pie)

      Copyright (c) 2014-2015 Benjamin Keen
      [MIT License](https://github.com/benkeen/d3pie/blob/master/LICENSE)

-   [jQuery Sparklines](http://omnipotent.net/jquery.sparkline/)

      Copyright 2009-2012, Splunk Inc.
      [New BSD License](http://opensource.org/licenses/BSD-3-Clause)

-   [Peity](http://benpickles.github.io/peity/)

      Copyright 2009-2015, Ben Pickles
      [MIT License](https://github.com/benpickles/peity/blob/master/LICENCE)

-   [morris.js](http://morrisjs.github.io/morris.js/)

      Copyright 2013, Olly Smith
      [Simplified BSD License](http://morrisjs.github.io/morris.js/)

-   [Raphaël](http://dmitrybaranovskiy.github.io/raphael/)

      Copyright 2008, Dmitry Baranovskiy
      [MIT License](http://dmitrybaranovskiy.github.io/raphael/license.html)

-   [C3](http://c3js.org/)

      Copyright 2013, Masayuki Tanaka
      [MIT License](https://github.com/masayuki0812/c3/blob/master/LICENSE)

-   [D3](http://d3js.org/)

      Copyright 2015, Mike Bostock
      [BSD License](http://opensource.org/licenses/BSD-3-Clause)

-   [jQuery](https://jquery.org/)

      Copyright 2015, jQuery Foundation
      [MIT License](https://jquery.org/license/)

-   [Bootstrap](http://getbootstrap.com/getting-started/)

      Copyright 2015, Twitter
      [MIT License](https://github.com/twbs/bootstrap/blob/v4-dev/LICENSE)

-   [Bootstrap Toggle](http://www.bootstraptoggle.com/)

      Copyright (c) 2011-2014 Min Hur, The New York Times Company
      [MIT License](https://github.com/minhur/bootstrap-toggle/blob/master/LICENSE)

-   [Bootstrap-slider](http://seiyria.com/bootstrap-slider/)

      Copyright 2017 Kyle Kemp, Rohit Kalkur, and contributors
      [MIT License](https://github.com/seiyria/bootstrap-slider/blob/master/LICENSE.md)

-   [bootstrap-table](http://bootstrap-table.wenzhixin.net.cn/)

      Copyright (c) 2012-2016 Zhixin Wen [wenzhixin2010@gmail.com](mailto:wenzhixin2010@gmail.com)
      [MIT License](https://github.com/wenzhixin/bootstrap-table/blob/master/LICENSE)

-   [tableExport.jquery.plugin](https://github.com/hhurz/tableExport.jquery.plugin)

      Copyright (c) 2015,2016 hhurz
      [MIT License](https://github.com/hhurz/tableExport.jquery.plugin/blob/master/LICENSE)

-   [perfect-scrollbar](https://jamesflorentino.github.io/nanoScrollerJS/)

      Copyright 2016, Hyunje Alex Jun and other contributors
      [MIT License](https://github.com/noraesae/perfect-scrollbar/blob/master/LICENSE)

-   [FontAwesome](https://fortawesome.github.io/Font-Awesome/)

      Created by Dave Gandy
      Font license: [SIL OFL 1.1](http://scripts.sil.org/OFL)
      Icon license [Creative Commons Attribution 4.0 (CC-BY 4.0)](https://creativecommons.org/licenses/by/4.0/)
      Code license: [MIT License](http://opensource.org/licenses/mit-license.html)

-   [node-extend](https://github.com/justmoon/node-extend)

      Copyright 2014, Stefan Thomas
      [MIT License](https://github.com/justmoon/node-extend/blob/master/LICENSE)

-   [node-net-snmp](https://github.com/stephenwvickers/node-net-snmp)

      Copyright 2013, Stephen Vickers
      [MIT License](https://github.com/nospaceships/node-net-snmp#license)

-   [node-asn1-ber](https://github.com/stephenwvickers/node-asn1-ber)

      Copyright 2017, Stephen Vickers
      Copyright 2011, Mark Cavage
      [MIT License](https://github.com/nospaceships/node-asn1-ber#license)

-   [pixl-xml](https://github.com/jhuckaby/pixl-xml)

      Copyright 2015, Joseph Huckaby
      [MIT License](https://github.com/jhuckaby/pixl-xml#license)

-   [sensors](https://github.com/paroj/sensors.py)

      Copyright 2014, Pavel Rojtberg
      [LGPL 2.1 License](http://opensource.org/licenses/LGPL-2.1)

-   [PyYAML](https://bitbucket.org/blackjack/pysensors)

      Copyright 2006, Kirill Simonov
      [MIT License](https://github.com/yaml/pyyaml/blob/master/LICENSE)

-   [urllib3](https://github.com/shazow/urllib3)

      Copyright 2008-2016 Andrey Petrov and [contributors](https://github.com/shazow/urllib3/blob/master/CONTRIBUTORS.txt)
      [MIT License](https://github.com/shazow/urllib3/blob/master/LICENSE.txt)

-   [lz-string](http://pieroxy.net/blog/pages/lz-string/index.html)

      Copyright 2013 Pieroxy
      [WTFPL License](http://pieroxy.net/blog/pages/lz-string/index.html#inline_menu_10)

-   [pako](http://nodeca.github.io/pako/)

      Copyright 2014-2017 Vitaly Puzrin and Andrei Tuputcyn
      [MIT License](https://github.com/nodeca/pako/blob/master/LICENSE)

-   [clipboard-polyfill](https://github.com/lgarron/clipboard-polyfill)

      Copyright (c) 2014 Lucas Garron
      [MIT License](https://github.com/lgarron/clipboard-polyfill/blob/master/LICENSE.md)

-   [Utilities for writing code that runs on Python 2 and 3](https://raw.githubusercontent.com/netdata/netdata/master/collectors/python.d.plugin/python_modules/urllib3/packages/six.py)

      Copyright (c) 2010-2015 Benjamin Peterson
      [MIT License](https://github.com/benjaminp/six/blob/master/LICENSE)

-   [mcrcon](https://github.com/barneygale/MCRcon)

      Copyright (C) 2015 Barnaby Gale
      [MIT License](https://raw.githubusercontent.com/barneygale/MCRcon/master/COPYING.txt)

-   [monotonic](https://github.com/atdt/monotonic)

      Copyright 2014, 2015, 2016 Ori Livneh [ori@wikimedia.org](mailto:ori@wikimedia.org)
      [Apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

-   [filelock](https://github.com/benediktschmitt/py-filelock)

    Copyright 2015, Benedikt Schmitt [Unlicense License](https://unlicense.org/)

[![analytics](https://www.google-analytics.com/collect?v=1&aip=1&t=pageview&_s=1&ds=github&dr=https%3A%2F%2Fgithub.com%2Fnetdata%2Fnetdata&dl=https%3A%2F%2Fmy-netdata.io%2Fgithub%2FREDISTRIBUTED&_u=MAC~&cid=5792dfd7-8dc4-476b-af31-da2fdb9f93d2&tid=UA-64295674-3)](<>)
